# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TypesBillingPeriod(str, Enum):
    """
    TypesBillingPeriod
    """

    """
    allowed enum values
    """
    MONTHLY = 'MONTHLY'
    ANNUAL = 'ANNUAL'
    WEEKLY = 'WEEKLY'
    DAILY = 'DAILY'
    QUARTERLY = 'QUARTERLY'
    HALF_YEARLY = 'HALF_YEARLY'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TypesBillingPeriod from a JSON string"""
        return cls(json.loads(json_str))


